@@ -1,11 +1,14 @@
+#ifndef INCLUDED_CRYPTSETUP_LUKS_LUKS_H
+#define INCLUDED_CRYPTSETUP_LUKS_LUKS_H
+
 /*
  * LUKS partition header
  */
 
+#include <stddef.h>
 #include <netinet/in.h>
 #include "libcryptsetup.h"
 #include "internal.h"
-     
 
 #define LUKS_CIPHERNAME_L 32
 #define LUKS_CIPHERMODE_L 32
@@ -38,6 +41,10 @@
 /* Actually we need only 37, but we don't want struct autoaligning to kick in */
 #define UUID_STRING_L 40
 
+/* We don't have gettext support in LUKS */
+
+#define _(Text) Text 
+
 /* Any integer values are stored in network byte order on disk and must be
 converted */
 
@@ -68,7 +75,7 @@ struct luks_phdr {
 };
 
 struct luks_masterkey {
-	int keyLength;
+	size_t keyLength;
 	char key[32];
 };
 
@@ -77,7 +84,6 @@ int LUKS_generate_masterkey(struct luks_masterkey *mk);
 int LUKS_generate_phdr(struct luks_phdr *header,
 		       const struct luks_masterkey *mk, const char *cipherName,
 		       const char *cipherMode, unsigned int stripes);
-	
 
 int LUKS_read_phdr(const char *device, struct luks_phdr *hdr);
 
@@ -86,7 +92,7 @@ int LUKS_write_phdr(const char *device, struct luks_phdr *hdr);
 int LUKS_set_key(const char *device, 
 					unsigned int keyIndex, 
 					const char *password, 
-					unsigned int passwordLen, 
+					size_t passwordLen, 
 					struct luks_phdr *hdr, 
 					struct luks_masterkey *mk,
 					struct setup_backend *backend);
@@ -94,14 +100,14 @@ int LUKS_set_key(const char *device,
 int LUKS_open_key(const char *device, 
 					unsigned int keyIndex, 
 					const char *password, 
-					unsigned int passwordLen, 
+					size_t passwordLen, 
 					struct luks_phdr *hdr, 
 					struct luks_masterkey *mk,
 					struct setup_backend *backend);
 
 int LUKS_open_any_key(const char *device, 
 					const char *password, 
-					unsigned int passwordLen, 
+					size_t passwordLen, 
 					struct luks_phdr *hdr, 
 					struct luks_masterkey *mk,
 					struct setup_backend *backend);
@@ -110,14 +116,16 @@ int LUKS_del_key(const char *device, unsigned int keyIndex);
 int LUKS_is_last_keyslot(const char *device, unsigned int keyIndex);
 int LUKS_benchmarkt_iterations();
 
-int LUKS_encrypt_to_storage(char *src, unsigned int srcLength,
+int LUKS_encrypt_to_storage(char *src, size_t srcLength,
 			    struct luks_phdr *hdr,
-			    char *key, unsigned int keyLength,
+			    char *key, size_t keyLength,
 			    const char *device,
 			    unsigned int sector, struct setup_backend *backend);
 	
-int LUKS_decrypt_from_storage(char *dst, unsigned int dstLength,
+int LUKS_decrypt_from_storage(char *dst, size_t dstLength,
 			      struct luks_phdr *hdr,
-			      char *key, unsigned int keyLength,
+			      char *key, size_t keyLength,
 			      const char *device,
 			      unsigned int sector, struct setup_backend *backend);
+
+#endif
